@@ -14,24 +14,24 @@ def build_config() -> dict[str, str]:
     """
     return dict(
         # Python settings
-        python_version="3.12",
-        python_install_dir=r"/usr/local/lib/python3.12/site-packages/",
+        python_version="3.13",
+        python_install_dir=r"/usr/local/lib/python3.13/site-packages/",
         python_path=r"/usr/bin/python",
 
         # Package versions
         contourpy_version="1.3.1",
-        meson_version="1.6.0",
+        meson_version="1.6.1",
         mesonpy_version="0.17.1",
         pybind11_version="2.13.6",
 
         # Misc meson settings
         meson_backend="ninja",
-        build_dir=r"/build/python-contourpy/src/contourpy/.mesonpy-g39a3r6y/lib/contourpy/util",
+        build_dir=r"/build/python-contourpy/src/contourpy/.mesonpy-576sszjt/lib/contourpy/util",
         source_dir=r"/build/python-contourpy/src/contourpy/lib/contourpy/util",
         cross_build="False",
 
         # Build options
-        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md -Dvsenv=True --native-file=/build/python-contourpy/src/contourpy/.mesonpy-g39a3r6y/meson-python-native-file.ini",
+        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md -Dvsenv=True --native-file=/build/python-contourpy/src/contourpy/.mesonpy-576sszjt/meson-python-native-file.ini",
         buildtype="release",
         cpp_std="c++17",
         debug="False",
